pub struct ParseResult<'buffer> {
pub remainder: &'buffer str,
pub index: Option<usize>,
pub marker: Option<&'buffer str>,
pub action: ParseAction,
}Expand description
Index result obtained from parsing a string with an index marker For example, the next string: “this is an example :10”
Contains an index marker :10. This marker indicates that the user may want to select the 10th element from a list
Fields
remainder: &'buffer strText before the marker
index: Option<usize>Parsed value from the marker
marker: Option<&'buffer str>Marker representation as string
action: ParseActionDirection of the search based on the marker